{% load i18n %}
{% load url from future %}
{% comment %}
    Form rendered from {% wishlist_remove_form <item> %} template tag.
{% endcomment %}
<form action="{% url 'wishlist_remove' pk=item.wishlistitem_set.all.0.pk %}" method="post">
    {% csrf_token %}
    <input type="submit" value="{% trans 'Remove' %}">
</form>
