{% extends "base.html" %}

{% load i18n %}
{% load url from future %}

{% block htmltitle %}{% trans 'Remove item from wishlist' %}{% endblock %}
{% block title %}{% trans 'Remove item from wishlist' %}{% endblock %}

{% block content %}
    {% blocktrans %}Are you sure you want to remove {{ form.instance }} from your wishlist?{% endblocktrans %}
    <form action="." method="post">
        {% csrf_token %}
        {{ form }}
        <input type="submit" value="{% trans 'Confirm' %}">
    </form>

    <nav>
        <a href="{% url 'wishlist' %}">{% trans 'Back to the wishlist' %}</a>
    </nav>
{% endblock content %}
