{% load i18n %}<!DOCTYPE html>
<html>
<head>
    <title>{% block htmltitle %}{% endblock %}</title>
</head>
<body>
    <section class="header">
        <h1>{% block title %}{% endblock %}</h1>

        {% comment %}Show number of items - ugly syntax awaiting trimmed option{% endcomment %}
        {% blocktrans count counter=wishlist_items.count %}1 item in wishlist{% plural %}{{ counter }} items in wishlist{% endblocktrans %}
    </section>
    <section class="messages">
        {% block messages %}
            {% if messages %}
                <h2>Messages</h2>
                <ul class="messages">
                    {% for message in messages %}
                        <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
        {% endblock messages %}
    </section>
    <section class="content">
        {% block content %}{% endblock %}
    </section>
</body>
</html>
